@@ -1,5 +1,5 @@
 from jobqueues.localqueue import LocalGPUQueue
-from protocolinterface import ProtocolInterface, val
+from protocolinterface import val
 from jobqueues.config import loadConfig
 import os
 import logging
@@ -67,7 +67,7 @@ class CeleryQueue(LocalGPUQueue):
         try:
             from jobqueues.celeryfiles.tasks import execute_gpu_job, execute_cpu_job
 
-            self._submitfunc = {"gpu": execute_gpu_job, "cpu": execute_cpu_job}
+            self._submitfunc = {"gpu": app.task(execute_gpu_job), "cpu": app.task(execute_cpu_job)}
         except Exception as e:
             raise RuntimeError(f"Could not import CeleryQueue task with error {e}")
 
@@ -110,7 +110,7 @@ class CeleryQueue(LocalGPUQueue):
                 func = self._submitfunc["gpu"]
             else:
                 func = self._submitfunc["cpu"]
-            async_res = func.delay(
+            _ = func.delay(
                 dirname,
                 runscript,
                 self._sentinel,
