@@ -10,7 +10,7 @@ import string
 from jobqueues.config import loadConfig
 import yaml
 from subprocess import check_output, CalledProcessError
-from protocolinterface import ProtocolInterface, val
+from protocolinterface import val
 from jobqueues.simqueue import SimQueue, QueueJobStatus, _inProgressStatus
 from jobqueues.util import ensurelist
 import getpass
@@ -39,7 +39,7 @@ JOB_STATE_CODES = {
 }
 
 
-class SlurmQueue(SimQueue, ProtocolInterface):
+class SlurmQueue(SimQueue):
     """Queue system for SLURM
 
     Parameters
@@ -103,8 +103,7 @@ class SlurmQueue(SimQueue, ProtocolInterface):
     def __init__(
         self, _configapp=None, _configfile=None, _findExecutables=True, _logger=True
     ):
-        SimQueue.__init__(self)
-        ProtocolInterface.__init__(self)
+        super().__init__()
         self._arg("jobname", "str", "Job name (identifier)", None, val.String())
         self._arg(
             "partition",
@@ -238,6 +237,27 @@ class SlurmQueue(SimQueue, ProtocolInterface):
             True,
             val.Boolean(),
         )
+        self._arg(
+            "nodes",
+            "int",
+            "Number of nodes to request",
+            None,
+            val.Number(int, "0POS"),
+        )
+        self._arg(
+            "ntasks",
+            "int",
+            "Total number of tasks",
+            None,
+            val.Number(int, "0POS"),
+        )
+        self._arg(
+            "ntasks_per_node",
+            "int",
+            "Number of tasks each node will run",
+            None,
+            val.Number(int, "0POS"),
+        )
 
         # Load Slurm configuration profile
         loadConfig(self, "slurm", _configfile, _configapp, _logger)
@@ -302,7 +322,7 @@ class SlurmQueue(SimQueue, ProtocolInterface):
             if self.gpumemory is not None:
                 gpustring += f",gpu_mem:{self.gpumemory}"
 
-        prerun = self.prerun if self.prerun is not None else []
+        prerun = self.prerun.copy() if self.prerun is not None else []
         errorstream = self.errorstream
         outputstream = self.outputstream
         if not self.useworkdir:
@@ -340,6 +360,9 @@ class SlurmQueue(SimQueue, ProtocolInterface):
             runsh=runsh,
             odir=odir,
             trajext=self.trajext,
+            nodes=self.nodes,
+            ntasks=self.ntasks,
+            ntasks_per_node=self.ntasks_per_node,
         )
         with open(fname, "w") as f:
             f.write(job_str)
@@ -356,7 +379,7 @@ class SlurmQueue(SimQueue, ProtocolInterface):
             + "".join([random.choice(string.digits) for _ in range(5)])
         )
 
-    def submit(self, dirs, commands=None):
+    def submit(self, dirs, commands=None, _dryrun=False):
         """Submits all directories
 
         Parameters
@@ -379,11 +402,14 @@ class SlurmQueue(SimQueue, ProtocolInterface):
             runscript = commands[i] if commands is not None else self._getRunScript(d)
             self._cleanSentinel(d)
 
-            jobscript = os.path.abspath(os.path.join(d, "job.sh"))
+            jobscript = os.path.abspath(os.path.join(d, self.jobscript))
             self._createJobScript(jobscript, d, runscript)
             try:
-                ret = check_output([self._qsubmit, jobscript])
-                logger.debug(ret.decode("ascii"))
+                if _dryrun:
+                    logger.info(f"Dry run. Here it would call submit on {jobscript}")
+                else:
+                    ret = check_output([self._qsubmit, jobscript])
+                    logger.debug(ret.decode("ascii"))
             except CalledProcessError as e:
                 logger.error(e.output)
                 raise
@@ -672,6 +698,69 @@ class _TestSlurmQueue(unittest.TestCase):
                     l1 == l2
                 ), f"Difference found in line {i} of job file: {l1} vs {l2}"
 
+    def test_submit_multi_folder(self):
+        import tempfile
+
+        with tempfile.TemporaryDirectory() as tmpdir:
+            sl = SlurmQueue(_findExecutables=False)
+            sl.partition = "jobqueues_test"
+            sl.ngpu = 2
+            sl.gpumemory = 2000
+            sl.exclude = ["node1", "node4"]
+            sl.nodelist = ["node2"]
+            sl.envvars = "TEST=3"
+
+            for i in range(2):
+                subdir = os.path.join(tmpdir, str(i))
+                os.makedirs(subdir, exist_ok=True)
+                with open(os.path.join(subdir, "run.sh"), "w") as f:
+                    f.write("sleep 5")
+                os.chmod(os.path.join(subdir, "run.sh"), 0o700)
+
+                try:
+                    sl.submit(subdir)
+                except Exception as e:
+                    print(e)
+                    pass
+
+                with open(os.path.join(subdir, "job.sh"), "r") as f:
+                    joblines = f.readlines()
+
+                reflines = [
+                    "#!/bin/bash\n",
+                    "#\n",
+                    "#SBATCH --job-name=tmp8dj2zuya_44185\n",
+                    "#SBATCH --partition=jobqueues_test\n",
+                    "#SBATCH --cpus-per-task=1\n",
+                    "#SBATCH --mem=1000\n",
+                    "#SBATCH --priority=None\n",
+                    "#SBATCH -D tmpdir\n",
+                    "#SBATCH --gres=gpu:2,gpu_mem:2000\n",
+                    "#SBATCH --output=slurm.%N.%j.out\n",
+                    "#SBATCH --error=slurm.%N.%j.err\n",
+                    "#SBATCH --export=TEST=3\n",
+                    "#SBATCH --nodelist=node2\n",
+                    "#SBATCH --exclude=node1,node4\n",
+                    "\n",
+                    'trap "touch tmpdir/jobqueues.done" EXIT SIGTERM\n',
+                    "\n",
+                    "cd tmpdir\n",
+                    "\n",
+                    "tmpdir/run.sh\n",
+                    "\n",
+                ]
+                skiplines = [2]
+
+                assert len(joblines) == len(reflines)
+                for i, (l1, l2) in enumerate(zip(reflines, joblines)):
+                    l1 = l1.replace(subdir, "tmpdir")
+                    l2 = l2.replace(subdir, "tmpdir")
+                    if i in skiplines:
+                        continue
+                    assert (
+                        l1 == l2
+                    ), f"Difference found in line {i} of job file: {l1} vs {l2}"
+
 
 if __name__ == "__main__":
     unittest.main(verbosity=2)
